# Script for the analisys and graphs used in:
# Climate effects on fish body size-trophic position relationship depend on ecosystem type - ECOGRAPHY - Dantas et al. 2019
#


# Required library

library(mgcv)

# load data

data<-read.csv("Appendix_S1.csv", header=T) # set your working directory to the source script location or move the .csv file to your current working directory

View(data)

summary(data$Troph_posit)

#Split the dataset for Climates and Habitats

dados_salt<-subset(data, Habitat == "Saltwater")

dados_fresh<-subset(data, Habitat == "Freshwater")


# Models for the values presented in Table 1 

# GAMM for saltwater 

M1<-bam((Troph_posit)~s((Max_total_body_length..cm.),fx=FALSE, k=-1,bs="cr")+ s((Max_total_body_length..cm.),fx=FALSE, k=-1,bs="cr", by = as.numeric(Climate == "tropical"))+  s(Order, bs="re")+  s(Family, bs="re") +  s(Genus, bs="re") + Climate,data=dados_salt)

summary(M1)
anova(M1)

# GAMM for freshwater

M2<-bam((Troph_posit)~s((Max_total_body_length..cm.),fx=FALSE, k=-1,bs="cr")+ s((Max_total_body_length..cm.),by = as.numeric(Climate == "tropical"),fx=FALSE, k=-1,bs="cr")+  s(Order, bs="re")+ s(Family, bs="re")+  s(Genus, bs="re") + Climate, data=dados_fresh)


summary(M2)
anova(M2)

# Graphs in figure 1
# Models with only signifcant smoother terms

M1<-bam((Troph_posit)~s((Max_total_body_length..cm.),fx=FALSE, k=-1,bs="cr")+s(Order, bs="re")+  s(Family, bs="re") +  s(Genus, bs="re") + Climate,data=dados_salt) 

M2<-bam((Troph_posit)~s((Max_total_body_length..cm.),fx=FALSE, k=-1,bs="cr")+ s((Max_total_body_length..cm.),by = as.numeric(Climate == "tropical"),fx=FALSE, k=-1,bs="cr")+  s(Order, bs="re")+ s(Family, bs="re")+  s(Genus, bs="re") + Climate, data=dados_fresh)


plot(M1)
plot (M2)

# Graphs in figure 2

vis.gam(M1, theta = 50, color = "cm")
vis.gam(M2, theta = 50, color = "cm")


#end
